exceptiontools.InstrumentError
==============================

.. inheritance-diagram:: abjad.tools.exceptiontools.InstrumentError.InstrumentError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.InstrumentError.InstrumentError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
